Imports LangLib
Imports System.Windows.Forms
''' <summary>
''' Defines a type of application and it's rules to manage files and to build.
''' </summary>
Public MustInherit Class ApplicationType
    Public MustOverride ReadOnly Property isParsed() As Boolean
    ''' <summary>
    ''' Full name of the application type.
    ''' </summary>
    Public MustOverride ReadOnly Property name() As String
    ''' <summary>
    ''' List of types of the options of the application.
    ''' </summary>
    Public MustOverride ReadOnly Property OptionTypes() As List(Of ApplicationOptionType)
    ''' <summary>
    ''' Called at the request to set the options of the application.
    ''' </summary>
    ''' <param name="app">Application to set the options.</param>
    Public MustOverride Sub editOptions(ByRef app As ProjectApplication)
    ''' <summary>
    ''' Called at the building of the application. Mustn't be overrided in parsed application types.
    ''' </summary>
    ''' <param name="app">Information about the application to build.</param>
    ''' <param name="dir">Directory where build the application.</param>
    ''' <returns>Details about the output of the building.</returns>
    Public MustOverride Function build(ByVal app As ProjectApplication, ByVal dir As String) As BuildingOutput
    ''' <summary>
    ''' Called at the request to run the application.
    ''' </summary>
    ''' <param name="dir">Absolute path of the directory where the app has been built. For parsed application types, it's the source directory.</param>
    Public MustOverride Sub run(ByVal dir As String)
    ''' <summary>
    ''' Called at the request to open a file with the specified extension.
    ''' </summary>
    ''' <param name="ext">File's extension.</param>
    ''' <param name="l">Array of languages. I you return a code editor pass this parameter to its constructor.</param>
    ''' <returns>Editor that will be added as a tab. It can be a code editor, a custom WYSIWYG editor or nothing if the file will be opened in a different application.</returns>
    Public MustOverride Function getDefaultEditor(ByVal ext As String, ByVal l As Language()) As Editor

    Public Function optionExists(ByVal n As String) As Boolean
        Try
            optionType(n)
            Return True
        Catch ex As Exception
            Return False
        End Try
    End Function

    Public Function optionType(ByVal n As String) As ApplicationOptionType
        For Each i As ApplicationOptionType In OptionTypes
            If i.name = n Then
                Return i
            End If
        Next
        Throw New ArgumentException(getMsg("optionTypeNotFound"))
    End Function
End Class

''' <summary>
''' Defines a type of application that needs to be built to run.
''' </summary>
Public MustInherit Class CompiledApplicationType
    Inherits ApplicationType

    Public Overrides ReadOnly Property isParsed() As Boolean
        Get
            Return False
        End Get
    End Property
End Class

''' <summary>
''' Defines a type of application that doesn't need to be built to run.
''' </summary>
Public MustInherit Class ParsedApplicationType
    Inherits ApplicationType

    Public Overrides ReadOnly Property isParsed() As Boolean
        Get
            Return True
        End Get
    End Property

    Public Overrides Function build(ByVal app As ProjectApplication, ByVal dir As String) As BuildingOutput
        My.Computer.FileSystem.WriteAllText(dir & "\README.txt", "The application " & app.Name & " is of the type """ & Me.name & """, so i doesn't need to be built to run. The application can be runnede directly from it's source.", False)
        Dim o As New BuildingOutput
        o.log.add("This application is of a parsed type, no building is needed.")
        Return o
    End Function
End Class