Imports System.Windows.forms
''' <summary>
''' Contains the rules for the sintax highlighting and eventually the code completion of the language.
''' </summary>
Public MustInherit Class Language
    Private Declare Function LockWindowUpdate Lib "user32" (ByVal hWnd As Integer) As Integer

    ''' <summary>
    ''' Call this function before the highlighting (this will lock the update of the window).
    ''' </summary>
    ''' <param name="rtb"></param>
    Public Sub lock(ByVal rtb As RichTextBox)
        LockWindowUpdate(rtb.Handle.ToInt32)
    End Sub

    ''' <summary>
    ''' Call this function after the highlighting (this will unlock the update of the window).
    ''' </summary>
    ''' <remarks></remarks>
    Public Sub unlock()
        LockWindowUpdate(0)
    End Sub

    ''' <summary>
    ''' Full name of the language.
    ''' </summary>
    Public MustOverride ReadOnly Property name() As String

    ''' <summary>
    ''' Places where can be found code in this language.
    ''' </summary>
    Public MustOverride ReadOnly Property pos() As List(Of LanguagePosition)

    ''' <summary>
    ''' Method that will be called when some code in this language has been edited. Do the syntax highlighting and eventually the code completion in this method.
    ''' </summary>
    ''' <param name="rtb">Windows Forms RichTextBox control where the code has been edited.</param>
    ''' <param name="p">Value that indicates if the code has been pasted. If language's syntax allows it, to optimize the performances, the highlighting should be done only on the current line, except if p is true.</param>
    ''' <param name="f">Index of the first char of the piece of code to elaborate.</param>
    ''' <param name="t">Index if the last char of the piece of code to elaborate.</param>
    Public MustOverride Sub textEdited(ByRef rtb As RichTextBox, ByVal p As Boolean, ByVal f As Integer, ByVal t As Integer)
End Class