''' <summary>
''' Abstract class that represents a position where can be found a determinate language.
''' </summary>
Public MustInherit Class LanguagePosition
    Public Shared Operator =(ByVal a As LanguagePosition, ByVal b As LanguagePosition) As Boolean
        If a.GetType().Name = b.GetType().Name Then
            If a.GetType().Name = "LanguagePosition_FullFile" Then
                Return CType(a, LanguagePosition_FullFile).ext = CType(b, LanguagePosition_FullFile).ext
            ElseIf a.GetType().Name = "LanguagePosition_InOtherFile" Then
                Dim a_ As LanguagePosition_InOtherLanguage = CType(a, LanguagePosition_InOtherLanguage)
                Dim b_ As LanguagePosition_InOtherLanguage = CType(b, LanguagePosition_InOtherLanguage)
                Return a_.container = b_.container And a_.beginStr = b_.beginStr And a_.endStr = b_.endStr
            End If
        Else
            Return False
        End If
    End Operator

    Public Shared Operator <>(ByVal a As LanguagePosition, ByVal b As LanguagePosition) As Boolean
        Return Not a = b
    End Operator
End Class

''' <summary>
''' Code written in this language can be found in a file with the specified extension.
''' </summary>
Public NotInheritable Class LanguagePosition_FullFile
    Inherits LanguagePosition
    Private _ext As String
    ''' <summary>
    ''' File's extension.
    ''' </summary>
    Public ReadOnly Property ext() As String
        Get
            Return _ext
        End Get
    End Property
    ''' <summary>
    ''' Initializes a new instance of the class LanguagePosition_FullFile.
    ''' </summary>
    ''' <param name="e">File's extension.</param>
    Sub New(ByVal e As String)
        _ext = e
    End Sub
End Class

''' <summary>
''' Code written in this language can be found in code written in other languages, delimited by specifc strings.
''' </summary>
Public NotInheritable Class LanguagePosition_InOtherLanguage
    Inherits LanguagePosition
    Private _container As String
    Private _beginStr As String
    Private _endStr As String
    ''' <summary>
    ''' Name of the language that contains code written in this language.
    ''' </summary>
    Public ReadOnly Property container() As String
        Get
            Return _container
        End Get
    End Property
    ''' <summary>
    ''' String that delimits the begin of the piece of code written in this language.
    ''' </summary>
    Public ReadOnly Property beginStr() As String
        Get
            Return _beginStr
        End Get
    End Property
    ''' <summary>
    ''' String that delimits the end of the piece of code written in this language.
    ''' </summary>
    Public ReadOnly Property endStr() As String
        Get
            Return _endStr
        End Get
    End Property
    ''' <summary>
    ''' Initializes a new istance of the class LanguagePosition_InOtherLanguage.
    ''' </summary>
    ''' <param name="cont">Name of the language that contains code written in this language.</param>
    ''' <param name="b">String that delimits the begin of the piece of code written in this language.</param>
    ''' <param name="e">String that delimits the end of the piece of code written in this language.</param>
    ''' <remarks></remarks>
    Sub New(ByVal cont As String, ByVal b As String, ByVal e As String)
        _container = cont
        _beginStr = b
        _endStr = e
    End Sub
End Class