Imports LangLib

<Serializable()> Public NotInheritable Class ProjectApplication
    ''' <summary>
    ''' Application's name.
    ''' </summary>
    Public Name As String
    ''' <summary>
    ''' Application's type.
    ''' </summary>
    Public AppType As String
    ''' <summary>
    ''' List of insormations about the files of the application.
    ''' </summary>
    Public AppFiles As New List(Of fileDetails)
    ''' <summary>
    ''' Application's options.
    ''' </summary>
    Public AppOptions As New List(Of ApplicationOption)
    <NonSerialized()> Public dir As String

    Sub New()
    End Sub

    Sub New(ByVal n As String, ByVal t As ApplicationType, ByVal prjRoot As String)
        Name = n
        AppType = t.name
        dir = prjRoot & "\src\" + Name
        For Each op As ApplicationOptionType In t.OptionTypes
            AppOptions.Add(New ApplicationOption(op.name, op.def))
        Next
        My.Computer.FileSystem.CreateDirectory(prjRoot & "\src\" + Name)
    End Sub

    Public Sub setFileOpen(ByVal file As String, Optional ByVal opened As Boolean = True)
        For Each f As fileDetails In AppFiles
            If f.p = file Then
                f.opened = opened
            End If
        Next
    End Sub

    ''' <summary>
    ''' Returns the absolute path of a file of this application.
    ''' </summary>
    ''' <param name="file">File of you want the path.</param>
    ''' <returns>File's absolute path.</returns>
    Public Function filePath(ByVal file As fileDetails) As String
        If dir <> "" Then
            Return dir & "\" & file.p
        Else
            Throw New ArgumentException(getMsg("appDirNotFound"))
        End If
    End Function

    ''' <summary>
    ''' Gets or sets the option with the specified name.
    ''' </summary>
    ''' <param name="n">Name of the option.</param>
    ''' <value>Value to assign to the option.</value>
    ''' <returns>Value of the option.</returns>
    Public Property appOption(ByVal n As String) As String
        Get
            Return AppOptions(optionId(n)).value
        End Get
        Set(ByVal value As String)
            AppOptions(optionId(n)).value = value
        End Set
    End Property

    Private Function optionId(ByVal n As String) As Integer
        For i As Integer = 0 To AppOptions.Count - 1
            Dim o As ApplicationOption = AppOptions(i)
            If o.name = n Then
                Return i
            End If
        Next
    End Function
End Class
